from setuptools import setup

setup(
    name='cutnorm',
    version='0.1.1',
    description=
    'Cutnorm approximation via Gaussian Rounding and Optimization with Orthogonality Constraints',
    url='https://github.com/pingkoc/cutnorm',
    author='Ping-Ko Chiu',
    author_email='pchiu5@illinois.edu',
    license='MIT',
    packages=['cutnorm'],
    zip_safe=False)
